Transaction

Struct Transaction 

pub struct Transaction {
    pub date: DateTime<Local>,
    pub check_number: Option<u32>,
    pub vendor: String,
    pub address: String,
    pub amount: f64,
    pub category: Option<String>,
    pub memo: String,
    pub status: Option<TransactionStatus>,
    pub splits: Vec<Split>,
}
structure that represents a regular transaction in a QIF file.

Fields

date: DateTime<Local>check_number: Option<u32>vendor: Stringaddress: Stringamount: f64category: Option<String>memo: Stringstatus: Option<TransactionStatus>splits: Vec<Split>

Implementations

Source

impl Transaction

pub fn from( date: DateTime<Local>, check_number: Option<u32>, vendor: String, address: String, amount: f64, category: Option<String>, memo: String, status: Option<TransactionStatus>, splits: Vec<Split>, ) -> Self

create a Tranaction object. The field are self explanatory, in what is expected.

However, this function is mainly used as a convenice initializer, though it can be used directly.

pub fn builder() -> TransactionBuilder

  • This method creates a builder that will help faciliate
  • in a creating transaction.
  • Transactions can then be made like this:
  • let sam_hill = Transaction::builder() .set_date(&today.format(format.chrono_str()).to_string(), &format) .set_check_number(1260) .set_vendor(“Sam Hill Credit Union”) .set_address(“Sam Hill Credit Union”) .set_category(“Opening Balance”) .set_amount(500.0) .set_memo(“Open Account”) .set_status(“*”) .build().unwrap();
pub fn to_string(&self, df: &DateFormat) -> String

pub fn from_str( s: &str, df: &DateFormat, ) -> Result<Self, TransactionBuildingError>